intelmq.bots.parsers.dyn package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.parsers.dyn package

## Submodules

## intelmq.bots.parsers.dyn.parser module

format: ponmocup-malware-IP ponmocup-malware-domain ponmocup-malware-URI-path ponmocup-htaccess-infected-domain

intelmq.bots.parsers.dyn.parser.BOT

  alias of `intelmq.bots.parsers.dyn.parser.DynParserBot`

class intelmq.bots.parsers.dyn.parser.DynParserBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ParserBot`

  Parse the DynDNS ponmocup feed

  init()
  process()

## Module contents